@@ -2,13 +2,13 @@ from io import BufferedReader
 from pathlib import Path
 from typing import Iterable, Type
 
-from devtools import debug
 import ijson
 from pydantic import ValidationError
 
 from dar_etl.schemas.base_model import DarBaseModel
 from dar_etl.schemas.root_keys import Root
 
+import logging
 
 class DarParser:
     def __init__(self, root: Root, parsing_type: Type[DarBaseModel]) -> None:
@@ -20,12 +20,12 @@ class DarParser:
             try:
                 yield from self.iterate_json(file_pointer=file_pointer)
             except ijson.IncompleteJSONError:
-                debug(self.root_key)
+                logging.error(self.root_key)
 
     def iterate_json(self, file_pointer: BufferedReader) -> Iterable[DarBaseModel]:
         for record in ijson.items(file_pointer, f"{self.root_key}.item"):
             try:
                 yield self.parsing_type(**record)
             except ValidationError as validation_error:
-                debug(record)
+                logging.error(record)
                 raise validation_error
